<?php

namespace FiloBlu\Flow\Block\Adminhtml\Channel\Edit\Tab;

use FiloBlu\Flow\Helper\Data;
use FiloBlu\Flow\Model\Inboundflow;
use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Form\Generic;
use Magento\Backend\Block\Widget\Tab\TabInterface;
use Magento\Cms\Model\Page;
use Magento\Framework\Data\Form;
use Magento\Framework\Data\FormFactory;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Registry;

/**
 * Class Config
 * @package FiloBlu\Flow\Block\Adminhtml\Channel\Edit\Tab
 */
class Config extends Generic implements TabInterface
{
    /**
     * @var Data
     */
    protected $helper;

    /**
     * @param Data $helper
     * @param Context $context
     * @param Registry $registry
     * @param FormFactory $formFactory
     * @param array $data
     */

    public function __construct(
        Data $helper,
        Context $context,
        Registry $registry,
        FormFactory $formFactory,
        array $data = array()
    )
    {

        $this->helper = $helper;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Prepare label for tab
     *
     * @return string
     */
    public function getTabLabel()
    {
        return __('Config');
    }

    /**
     * Prepare title for tab
     *
     * @return string
     */
    public function getTabTitle()
    {
        return __('config');
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden()
    {
        return false;
    }

    /**
     * Prepare form
     *
     * @return $this
     * @throws LocalizedException
     */
    protected function _prepareForm()
    {
        /* @var $model Page */
        $model = $this->_coreRegistry->registry('flow_channel');
        /** @var Form $form */
        $form = $this->_formFactory->create();

        $form->setHtmlIdPrefix('page_');

        $fieldset_config = $form->addFieldset('config_fieldset', ['legend' => __('Config')]);

        $afterElementHtml = '&nbsp;<small>' . ' Per Flow di tipo Multistock: installare anche filoblu/mod2-ext-msi' . '</small>';
        $fieldset_config->addField('flow', 'select', [
                'name' => 'config[flow]',
                'label' => __('Model / Flow'),
                'required' => true,
                'values' => $this->helper->getModels(),
                'after_element_html' => $afterElementHtml
            ]
        );

        $afterElementHtml = '&nbsp;<small>' . ' Per Flow di tipo Anagrafica: duplicare il file per generare il corrispondente Ite?' . '</small>';
        $fieldset_config->addField('copy_to_ite', 'select', [
                'name' => 'config[copy_to_ite]',
                'label' => __('Copy to Ite'),
                'required' => false,
                'values' => ['0' => 'No', '1' => 'Yes'],
                'default' => 0,
                'after_element_html' => $afterElementHtml
            ]
        );

        $fieldset_config->addField('process_reserved_stock', 'select', [
                'name' => 'config[process_reserved_stock]',
                'label' => __('Process Reserved Stock'),
                'required' => false,
                'values' => ['0' => 'No', '1' => 'Yes'],
                'default' => '1'
            ]
        );

        $fieldset_config->addField('ite_channel_name', 'text', [
                'name' => 'config[ite_channel_name]',
                'label' => __('Ite channel name'),
                'required' => false
            ]
        );

        $fieldset_config->addField('bus', 'select', [
            'label' => __('Bus'),
            'name' => 'config[bus]',
            'values' => ['1' => '1', '2' => '2', '3' => '3', '4' => '4'],
        ]);

        $fieldset_config->addField('priority', 'select', [
            'label' => __('Priority'),
            'name' => 'config[priority]',
            'values' => Inboundflow::getPriorityList()
        ]);

        $fieldset_config->addField('type', 'select', [
            'label' => __('Channel Type'),
            'name' => 'config[type]',
            'values' => ['file' => 'File', 'image' => 'Image', 'document' => 'Document'],
        ]);

        $form->setValues($model->getData('config'));
        $this->setForm($form);

        return parent::_prepareForm();
    }

    /**
     * Check permission for passed action
     *
     * @param string $resourceId
     * @return bool
     */
    protected function _isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }
}
